from django.contrib import admin

from .models import Break, Lesson, Slot, ValidityRange


def format_m2m(f, attr: str = "short_name") -> str:
    """Join a attribute of all elements of a ManyToManyField."""
    return ", ".join([getattr(x, attr) for x in f.all()])


class ValidityRangeAdmin(admin.ModelAdmin):
    list_display = ("__str__", "date_start", "date_end")
    list_display_links = ("__str__", "date_start", "date_end")


admin.site.register(ValidityRange, ValidityRangeAdmin)


class SlotAdmin(admin.ModelAdmin):
    list_display = ("validity_range", "name", "weekday", "period", "time_start", "time_end")
    list_display_links = ("weekday", "period")


admin.site.register(Slot, SlotAdmin)
admin.site.register(Break, SlotAdmin)


class LessonAdmin(admin.ModelAdmin):
    def _teachers(self, obj):
        return format_m2m(obj.teachers)

    def _rooms(self, obj):
        return format_m2m(obj.rooms)

    filter_horizontal = ["teachers", "groups"]
    list_filter = (
        "subject",
        "course__groups",
        "course__groups__parent_groups",
        "teachers",
        "rooms",
    )
    list_display = ("course", "slot_from", "slot_to", "subject", "_teachers", "_rooms")


admin.site.register(Lesson)
