import { hasPersonValidator } from "aleksis.core/routeValidators";

export default {
  component: () => import("aleksis.core/components/Parent.vue"),
  meta: {
    inMenu: true,
    titleKey: "lesrooster.menu_title",
    icon: "mdi-timetable",
    validators: [hasPersonValidator],
    permission: "lesrooster.view_lesrooster_menu_rule",
  },
  children: [
    {
      path: "validity-ranges/",
      component: () => import("./components/ValidityRange.vue"),
      name: "lesrooster.validity_ranges",
      meta: {
        inMenu: true,
        titleKey: "lesrooster.validity_range.menu_title",
        icon: "mdi-calendar-expand-horizontal-outline",
        permission: "lesrooster.view_validity_ranges_rule",
      },
    },
    {
      path: "raster/",
      component: () => import("./components/lesson_raster/LessonRaster.vue"),
      name: "lesrooster.lesson_raster",
      meta: {
        inMenu: true,
        titleKey: "lesrooster.lesson_raster.menu_title",
        toolbarTitle: "lesrooster.lesson_raster.menu_title",
        icon: "mdi-grid-large",
        permission: "lesrooster.view_lesson_raster_rule",
      },
    },
    {
      path: "timetable/:id(\\d+)/",
      component: () =>
        import("./components/timetable_management/TimetableManagement.vue"),
      name: "lesrooster.timetable_management",
      props: true,
      meta: {
        inMenu: true,
        titleKey: "lesrooster.timetable_management.menu_title",
        toolbarTitle: "lesrooster.timetable_management.menu_title",
        icon: "mdi-magnet",
        permission: "lesrooster.view_timetable_creation_rule",
      },
    },
    {
      path: "slots/",
      component: () => import("./components/LesroosterSlot.vue"),
      name: "lesrooster.slots",
      meta: {
        inMenu: true,
        titleKey: "lesrooster.slot.menu_title",
        icon: "mdi-border-none-variant",
        permission: "lesrooster.view_slots_rule",
      },
    },
    {
      path: "breaks/",
      component: () => import("./components/Break.vue"),
      name: "lesrooster.breaks",
      meta: {
        inMenu: true,
        titleKey: "lesrooster.break.menu_title",
        icon: "mdi-timer-sand-paused",
        permission: "lesrooster.view_breaks_rule",
      },
    },
    {
      path: "timebound_course_configs/",
      component: () =>
        import("./components/TimeboundCourseConfigCRUDTable.vue"),
      name: "lesrooster.timeboundCourseConfigs",
      meta: {
        inMenu: true,
        titleKey: "lesrooster.timebound_course_config.crud_table_menu_title",
        icon: "mdi-timetable",
        permission: "lesrooster.view_timebound_course_configs_rule",
      },
    },
    {
      path: "timebound_course_configs/plan_courses/",
      component: () => import("./components/TimeboundCourseConfigRaster.vue"),
      name: "lesrooster.planCourses",
      meta: {
        inMenu: true,
        titleKey: "lesrooster.timebound_course_config.raster_menu_title",
        icon: "mdi-clock-edit-outline",
        permission: "lesrooster.view_timebound_course_configs_rule",
      },
    },
  ],
};
