import graphene
from graphene_django.types import DjangoObjectType
from graphene_django_cud.mutations import (
    DjangoBatchCreateMutation,
    DjangoBatchDeleteMutation,
    DjangoBatchPatchMutation,
    DjangoCreateMutation,
)

from aleksis.core.schema.base import (
    DeleteMutation,
    DjangoFilterMixin,
    PermissionBatchDeleteMixin,
    PermissionBatchPatchMixin,
    PermissionsTypeMixin,
)

from ..models import Break
from .slot import slot_filters

break_filters = slot_filters.copy()
break_filters["period_after"] = break_filters.pop("period")


class BreakSlotType(PermissionsTypeMixin, DjangoFilterMixin, DjangoObjectType):
    model = graphene.String(default_value="Break")

    class Meta:
        model = Break
        fields = (
            "id",
            "validity_range",
            "name",
            "weekday",
            "period_after",
            "time_start",
            "time_end",
        )
        filter_fields = break_filters

    @classmethod
    def get_queryset(cls, queryset, info):
        return queryset  # FIXME filter this queryset based on permissions


class BreakSlotCreateMutation(DjangoCreateMutation):
    class Meta:
        model = Break
        return_field_name = "breakSlot"
        field_types = {"weekday": graphene.Int()}
        permissions = ("",)  # FIXME


class BreakSlotDeleteMutation(DeleteMutation):
    klass = Break
    permission_required = ""  # FIXME


class BreakSlotBatchCreateMutation(PermissionBatchPatchMixin, DjangoBatchCreateMutation):
    class Meta:
        model = Break
        return_field_name = "breakSlots"
        field_types = {"weekday": graphene.Int()}
        permissions = ("",)  # FIXME


class BreakSlotBatchDeleteMutation(PermissionBatchDeleteMixin, DjangoBatchDeleteMutation):
    class Meta:
        model = Break
        permissions = ("lesrooster.delete_break",)


class BreakSlotBatchPatchMutation(PermissionBatchPatchMixin, DjangoBatchPatchMutation):
    class Meta:
        model = Break
        return_field_name = "breakSlots"
        field_types = {"weekday": graphene.Int()}
        permissions = ("",)  # FIXME
