from graphene_django.types import DjangoObjectType
from graphene_django_cud.mutations import (
    DjangoBatchDeleteMutation,
    DjangoBatchPatchMutation,
    DjangoCreateMutation,
)

from aleksis.core.schema.base import (
    DeleteMutation,
    DjangoFilterMixin,
    PermissionBatchDeleteMixin,
    PermissionBatchPatchMixin,
    PermissionsTypeMixin,
)

from ..models import Lesson


class LessonType(PermissionsTypeMixin, DjangoFilterMixin, DjangoObjectType):
    class Meta:
        model = Lesson
        fields = ("id", "course", "slot_start", "slot_end", "rooms", "teachers", "subject")
        filter_fields = {
            "id": ["exact"],
            "slot_start": ["exact"],
            "slot_end": ["exact"],
        }

    @classmethod
    def get_queryset(cls, queryset, info):
        # FIXME filter this queryset based on permissions
        return queryset


class LessonCreateMutation(DjangoCreateMutation):
    class Meta:
        model = Lesson
        permissions = ("",)  # FIXME


class LessonDeleteMutation(DeleteMutation):
    klass = Lesson
    permission_required = ""  # FIXME


class LessonBatchDeleteMutation(PermissionBatchDeleteMixin, DjangoBatchDeleteMutation):
    class Meta:
        model = Lesson
        permissions = ("lesrooster.delete_validity_range",)


class LessonBatchPatchMutation(PermissionBatchPatchMixin, DjangoBatchPatchMutation):
    class Meta:
        model = Lesson
        permissions = ("",)  # FIXME
