import graphene
from graphene_django import DjangoListField
from graphene_django.types import DjangoObjectType
from graphene_django_cud.mutations import (
    DjangoBatchCreateMutation,
    DjangoBatchPatchMutation,
    DjangoCreateMutation,
)
from guardian.shortcuts import get_objects_for_user

from aleksis.apps.cursus.models import Course, Subject
from aleksis.apps.cursus.schema import CourseType, SubjectType
from aleksis.core.schema.base import (
    DeleteMutation,
    DjangoFilterMixin,
    PermissionBatchPatchMixin,
    PermissionsTypeMixin,
)

from ..models import TimeboundCourseConfig

timebound_course_config_filters = {"course": ["in"], "validity_range": ["in"], "teachers": [""]}


class TimeboundCourseConfigType(PermissionsTypeMixin, DjangoFilterMixin, DjangoObjectType):
    class Meta:
        model = TimeboundCourseConfig
        fields = ("id", "course", "validity_range", "scheduled_slot_count", "teachers")
        filter_fields = timebound_course_config_filters

    @classmethod
    def get_queryset(cls, queryset, info):
        return queryset  # FIXME filter this queryset based on permissions


class LesroosterExtendedCourseType(CourseType):
    class Meta:
        model = Course

    lr_timebound_course_configs = DjangoListField(TimeboundCourseConfigType)

    @staticmethod
    def resolve_lr_timebound_course_configs(root, info, **kwargs):
        return get_objects_for_user(
            info.context.user,
            "lesrooster.view_timeboundcourseconfig",
            root.lr_timebound_course_configs.all(),
        )


class LesroosterExtendedSubjectType(SubjectType):
    class Meta:
        model = Subject

    courses = DjangoListField(LesroosterExtendedCourseType)


class TimeboundCourseConfigCreateMutation(DjangoCreateMutation):
    class Meta:
        model = TimeboundCourseConfig
        fields = ("id", "course", "validity_range", "scheduled_slot_count", "teachers")
        permissions = ("",)  # FIXME


class TimeboundCourseConfigBatchCreateMutation(DjangoBatchCreateMutation):
    class Meta:
        model = TimeboundCourseConfig
        fields = ("id", "course", "validity_range", "scheduled_slot_count", "teachers")
        permissions = ("",)  # FIXME


class TimeboundCourseConfigDeleteMutation(DeleteMutation):
    klass = TimeboundCourseConfig
    permission_required = ""  # FIXME


class TimeboundCourseConfigBatchPatchMutation(PermissionBatchPatchMixin, DjangoBatchPatchMutation):
    class Meta:
        model = TimeboundCourseConfig
        fields = ("id", "course", "validity_range", "scheduled_slot_count", "teachers")
        permissions = ("",)  # FIXME
