from graphene_django.types import DjangoObjectType
from graphene_django_cud.mutations import (
    DjangoBatchDeleteMutation,
    DjangoBatchPatchMutation,
    DjangoCreateMutation,
)

from aleksis.core.schema.base import (
    DeleteMutation,
    DjangoFilterMixin,
    PermissionBatchDeleteMixin,
    PermissionBatchPatchMixin,
    PermissionsTypeMixin,
)

from ..models import ValidityRange


class ValidityRangeType(PermissionsTypeMixin, DjangoFilterMixin, DjangoObjectType):
    class Meta:
        model = ValidityRange
        fields = ("id", "school_term", "name", "date_start", "date_end")
        filter_fields = {
            "id": ["exact"],
            "school_term": ["exact", "in"],
            "name": ["icontains", "exact"],
            "date_start": ["exact", "lt", "lte", "gt", "gte"],
            "date_end": ["exact", "lt", "lte", "gt", "gte"],
        }

    @classmethod
    def get_queryset(cls, queryset, info):
        # FIXME filter this queryset based on permissions
        return queryset


class ValidityRangeCreateMutation(DjangoCreateMutation):
    class Meta:
        model = ValidityRange
        permissions = ("",)  # FIXME


class ValidityRangeDeleteMutation(DeleteMutation):
    klass = ValidityRange
    permission_required = ""  # FIXME


class ValidityRangeBatchDeleteMutation(PermissionBatchDeleteMixin, DjangoBatchDeleteMutation):
    class Meta:
        model = ValidityRange
        permissions = ("lesrooster.delete_validity_range",)


class ValidityRangeBatchPatchMutation(PermissionBatchPatchMixin, DjangoBatchPatchMutation):
    class Meta:
        model = ValidityRange
        permissions = ("",)  # FIXME
